%
%   fdbk_rho_081612.M    Post Analysis of Reactivty Feedback Expt.
%                               performed August 16, 2012
%
%   An experiment was performed in the UMLRR on Aug. 16, 2012.  The goal of this 
%   specific test was to measure the reactivtiy feedback (Xe and temp) effect in the 
%   UMLRR during the run.
% 
%   The experimental procedure was pretty simple: that is, the reactor was run 
%   at steady state at near full power (about 94-96%) for about 4 hours with no 
%   secondary cooling.  Note that the run was initiated after several days with no 
%   operations to assure that no xenon was present initially.  The secondary pump 
%   was turned off during the run because we wanted the pool temperature to increase 
%   during the experiment.  Note, however, that we were about 15 minutes into the 
%   expt before the secondary pump was turned off...
%   
%   During the constant power run, the regulating blade was put in auto mode, 
%   and it was observed to continually move out of the core over the duration of 
%   the experiment, while maintaining the reactor at the just critical state.  The 
%   positive reactivity associated with the RegBlade moving out was needed to 
%   compensate for the negative reactivity associated with the buildup of xenon 
%   and the increase in the average core temperature (with the secondary pump off, 
%   the pool temperature increased nearly linearly during the experiment).  The 
%   basic idea here is to compare the measured and estimated feedback reactivity 
%   that is developed over the 4-hr run within the UMLRR.
%
%   This example will be used twice as part of the Reactor Expts course, as follows:
%    1. First it will simply be used as an example for collecting, plotting, and 
%       analyzing the data from a particular reactor run.  This example will
%       highlight how to use the umlrr_data GUI to select a portion of a data file, 
%       create a *.dat file with the reduced data of interest, and then read this 
%       file within a Matlab script.  The data will be plotted and the RegBlade 
%       position vs. time data will be converted to reactivity worth vs time using 
%       an integral worth curve for the RegBlade.
%          *** These steps are done in this version of the Matlab file ***
%    
%    2. Later in the semester, we will use this file again when discussing reactivity
%       feedbacks.  This time, we will add a Xe and temperature feedback model and 
%       then compare how the analytical model compares to the measured results  --
%       this will allow us to determine how accurate the mathematical model 
%       represents reality...
%          *** This part of the analysis will be done later... ***
%
%   The raw reactor data for the run was downloaded from UMLRR Online and stored in 
%   a file called xenon+temp_test_081612.hst (this is a binary file).  This file is 
%   read by the umlrr_data GUI and converted to *.txt format (here the file was
%   called xenon+temp_test_081612.txt).  This dataset contains information for many 
%   different reactor measurements for the complete run (from when the reactor was 
%   started that day to when the data was downloaded).  By studying the run, one can 
%   isolate the time region of interest for the data analysis (here for about 4 hrs 
%   starting at 11:03 am).  At this point, one can save a reduced data file for only 
%   the region of interest and this can also contain averaged data over some time 
%   interval, if desired. The measurements are generally taken at 1 second intervals, 
%   but this info has been averaged over 30 sec periods and stored in a reduced data 
%   file called xenon_temp_feedback_081612.dat.  This is the file used in this Matlab
%   code...
%
%   The sequence of steps in the analysis is:
%     1. Read data file and plot some of the data to summarize reactor operations
%        during the run.  The most important parameters, of course, are the reg rod
%        position versus time and the core temperature vs time.  This can already be
%        done in the umlrr_data GUI but, by plotting it here, we can confirm that we
%        are reading the data correctly in this code...
%     2. Use the RegBlade worth curve generated during summer 2012 to get the total 
%        compensated reactivity vs time curve.
%          *** The above two steps are done in this version of the code ***
%     3. Use an analytical xenon model to predict the xenon reactivity vs time, and 
%        a simple temperature feedback model to estimate the temperature ccomponent.
%        The xenon model and temperature will be validated in separate experiments...
%     4. Compare the results from the xenon and temperature reactivty models with
%        the measure results from the experiment performed on Aug. 16, 2012...
%          *** Steps 3 + 4 will be done later in the semester... ***
%
%   File prepared by J. R. White, UMass-Lowell (last update: Jan. 2018)
%

      clear all, close all, nfig = 0;
%
%   read experimental data
      fname = 'xenon_temp_feedback_081612.dat';  
      [data,tags,exptdate,starttime] = read_datfile(fname); 
%
%   now lets plot some data to view reactor operation during the run
      te = data(:,1)/3600;                    % time vector for expt (hrs)
      tunits = 'hrs';  titl = 'FDBK\_\rho';    % plot annotation
      nfig = plot_PTB(te,data,tags,exptdate,nfig,titl,tunits); 
%
%   compute the total compensated reactivity vs time from the reg blade worth curve
      H =  [24.55 25.15 24.95 26.09 25.09];   % max blade traverse (inches)
      RBdate = 'Aug. 2012';
      c1 =  1.027e-6;  c2 = -6.807e-5;  c3 =  1.227e-3;    % Aug. 2012 'slow' data
      c4 =  8.897e-3;  c5 = -3.249e-1;  c6 = -2.671e-2;
      RBrho = @(z) c1*z.^4 + c2*z.^3 + c3*z.^2 + c4*z + c5 + c6*sin(2*pi*z/H(5));
      z = data(:,38);                   % reg blade position vs time (expt data)
      totrho = (RBrho(z)-RBrho(z(1)));  % total compensated reactivity (% Dk/k)
%
%   plot measured reactivity versus time
      nfig = nfig+1;  figure(nfig);
      rp = 0.95;  % relative power (fraction of full power) for edit purposes
      plot(te,totrho,'r-','LineWidth',2),grid
      title(['FDBK\_\rho:  Reactivity Changes Versus Time' ...
             ' (RP = ',num2str(rp,'%5.2f'),')'])
      xlabel('Elapsed Time (hours)'),ylabel('Reactivity Change (% \Deltak/k)')
%
%   just for discussion purposes, let's also plot the full blade worth curve
      nfig = nfig+1;  figure(nfig);
      zz = linspace(0,H(5),100);  worth = RBrho(zz)-RBrho(zz(1));
      plot(zz,worth,'r-','LineWidth',2),grid
      rr = axis;   rr(1:2) = [0 H(5)];   axis(rr)
      title(['FDBK\_\rho:  Integral RegBlade Worth Curve (from ',RBdate,')'])
      xlabel('distance withdrawn (inches)'),ylabel('Reactivity Worth (% \Deltak/k)')
%
%   end of program